@@ -22,7 +22,7 @@
 #include "k3btrack.h"
 #include "k3b_export.h"
 
-#include <KIOCore/KIO/Global>
+#include <KIO/Global>
 
 #include <QObject>
 #include <QString>
@@ -45,7 +45,7 @@ namespace K3b {
     public:
         AudioTrack();
         explicit AudioTrack( AudioDoc* parent );
-        ~AudioTrack();
+        ~AudioTrack() override;
 
         AudioDoc* doc() const;
 
